@@ -148,6 +148,24 @@ macro_rules! float_assertable_impl {
 
 eq_assertable_impl!(String);
 eq_assertable_impl!(str);
+eq_assertable_impl!(std::ffi::CString);
+eq_assertable_impl!(std::ffi::CStr);
+eq_assertable_impl!(std::ffi::OsString);
+eq_assertable_impl!(std::ffi::OsStr);
+eq_assertable_impl!(std::fs::FileType);
+eq_assertable_impl!(std::fs::Permissions);
+eq_assertable_impl!(std::net::Ipv4Addr);
+eq_assertable_impl!(std::net::Ipv6Addr);
+eq_assertable_impl!(std::net::SocketAddrV4);
+eq_assertable_impl!(std::net::SocketAddrV6);
+eq_assertable_impl!(std::path::Path);
+eq_assertable_impl!(std::path::PathBuf);
+eq_assertable_impl!(std::thread::ThreadId);
+eq_assertable_impl!(std::time::Duration);
+eq_assertable_impl!(std::time::Instant);
+eq_assertable_impl!(std::time::SystemTime);
+
+
 eq_assertable_impl!(bool);
 eq_assertable_impl!(u8);
 eq_assertable_impl!(i8);
@@ -162,6 +180,19 @@ eq_assertable_impl!(i128);
 eq_assertable_impl!(usize);
 eq_assertable_impl!(isize);
 
+eq_assertable_impl!(std::num::NonZeroU8);
+eq_assertable_impl!(std::num::NonZeroI8);
+eq_assertable_impl!(std::num::NonZeroU16);
+eq_assertable_impl!(std::num::NonZeroI16);
+eq_assertable_impl!(std::num::NonZeroU32);
+eq_assertable_impl!(std::num::NonZeroI32);
+eq_assertable_impl!(std::num::NonZeroU64);
+eq_assertable_impl!(std::num::NonZeroI64);
+eq_assertable_impl!(std::num::NonZeroU128);
+eq_assertable_impl!(std::num::NonZeroI128);
+eq_assertable_impl!(std::num::NonZeroUsize);
+eq_assertable_impl!(std::num::NonZeroIsize);
+
 float_assertable_impl!(f32);
 float_assertable_impl!(f64);
 
